SessionKeys

Struct SessionKeys 

pub struct SessionKeys {
    pub identity_key: Curve25519PublicKey,
    pub base_key: Curve25519PublicKey,
    pub one_time_key: Curve25519PublicKey,
}
The set of keys that were used to establish the Olm Session,

Fields

identity_key: Curve25519PublicKey

The long-term Curve25519PublicKey of the session initiator.

base_key: Curve25519PublicKey

The ephemeral Curve25519PublicKey created by the session initiator to establish the session.

one_time_key: Curve25519PublicKey

The one-time Curve25519PublicKey that the initiator downloaded from a key server, which was previously created and published by the recipient.

Implementations

Source

impl SessionKeys

pub fn session_id(&self) -> String

Returns the globally unique session ID which these SessionKeys will produce.

A session ID is the SHA256 of the concatenation of three SessionKeys, the account’s identity key, the ephemeral base key and the one-time key which is used to establish the session.

Due to the construction, every session ID is (probabilistically) globally unique.